==> flink-statefun-2.2.2-src.tgz: flink-statefun-2.2.2/statefun-flink/statefun-flink-core/src/main/java/org/apache/flink/statefun/flink/core/StatefulFunctionsUniverseValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.statefun.flink.core;

final class StatefulFunctionsUniverseValidator {

  void validate(StatefulFunctionsUniverse statefulFunctionsUniverse) {
    // TODO: complete this
    if (statefulFunctionsUniverse.ingress().isEmpty()) {
      throw new IllegalStateException("There are no ingress defined.");
    }
    if (statefulFunctionsUniverse.sources().isEmpty()) {
      throw new IllegalStateException("There are no source providers defined.");
    }
    if (statefulFunctionsUniverse.routers().isEmpty()) {
      throw new IllegalStateException("There are no routers defined.");
    }
    if (statefulFunctionsUniverse.functions().isEmpty()) {
      throw new IllegalStateException("There are no function providers defined.");
    }
  }
}

==> flink-statefun-3.3.0-src.tgz: flink-statefun-3.3.0/statefun-flink/statefun-flink-core/src/main/java/org/apache/flink/statefun/flink/core/StatefulFunctionsUniverseValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.statefun.flink.core;

final class StatefulFunctionsUniverseValidator {

  void validate(StatefulFunctionsUniverse statefulFunctionsUniverse) {
    // TODO: complete this
    if (statefulFunctionsUniverse.ingress().isEmpty()) {
      throw new IllegalStateException("There are no ingress defined.");
    }
    if (statefulFunctionsUniverse.sources().isEmpty()) {
      throw new IllegalStateException("There are no source providers defined.");
    }
    if (statefulFunctionsUniverse.routers().isEmpty()) {
      throw new IllegalStateException("There are no routers defined.");
    }
    if (statefulFunctionsUniverse.functions().isEmpty()
        && statefulFunctionsUniverse.namespaceFunctions().isEmpty()) {
      throw new IllegalStateException("There are no function providers defined.");
    }
  }
}
